@@ -112,6 +112,7 @@ int main(int argc, char *argv[])
 	DBusConnection *conn;
 	DBusError err;
 	struct sigaction sa;
+	mode_t old_umask;
 
 #ifdef NEED_THREADS
 	if (g_thread_supported() == FALSE)
@@ -156,6 +157,8 @@ int main(int argc, char *argv[])
 			perror("Failed to create storage directory");
 	}
 
+	old_umask = umask(077);
+
 	main_loop = g_main_loop_new(NULL, FALSE);
 
 #ifdef NEED_THREADS
@@ -205,8 +208,10 @@ int main(int argc, char *argv[])
 	__connman_profile_init(conn);
 
 	__connman_resolver_init();
+	__connman_ipconfig_init();
 	__connman_rtnl_init();
 	__connman_udev_init();
+	__connman_task_init();
 
 	__connman_plugin_init(option_plugin, option_noplugin);
 
@@ -231,8 +236,10 @@ int main(int argc, char *argv[])
 
 	__connman_plugin_cleanup();
 
+	__connman_task_cleanup();
 	__connman_udev_cleanup();
 	__connman_rtnl_cleanup();
+	__connman_ipconfig_cleanup();
 	__connman_resolver_cleanup();
 
 	__connman_profile_cleanup();
